require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xfilesystemaccessrule',
  dscmeta_resource_friendly_name: 'xFileSystemAccessRule',
  dscmeta_resource_name: 'MSFT_xFileSystemAccessRule',
  dscmeta_module_name: 'xSystemSecurity',
  dscmeta_module_version: '1.2.0.0',
  docs: 'The DSC xFileSystemAccessRule resource type.
         Automatically generated from version 1.2.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_path: {
      type: 'String',
      desc: 'The path to the item that should have permissions set',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rights: {
      type: "Optional[Array[Enum['ListDirectory', 'ReadData', 'WriteData', 'CreateFiles', 'CreateDirectories', 'AppendData', 'ReadExtendedAttributes', 'WriteExtendedAttributes', 'Traverse', 'ExecuteFile', 'DeleteSubdirectoriesAndFiles', 'ReadAttributes', 'WriteAttributes', 'Write', 'Delete', 'ReadPermissions', 'Read', 'ReadAndExecute', 'Modify', 'ChangePermissions', 'TakeOwnership', 'Synchronize', 'FullControl']]]",
      desc: 'The permissions to include in this rule, can be empty if ensure = absent',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_identity: {
      type: 'String',
      desc: 'The identity to set permissions for',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present to create the rule, Absent to remove an existing rule',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
